@@ -37,12 +37,8 @@ int _gnutls_handshake_buffer_empty( gnutls_session session);
 int _gnutls_handshake_buffer_get_ptr( gnutls_session session, char **data_ptr, size_t *length);
 
 #define _gnutls_handshake_io_buffer_clear( session) \
-        gnutls_free( session->internals.handshake_send_buffer.data); \
-        gnutls_free( session->internals.handshake_recv_buffer.data); \
-        session->internals.handshake_send_buffer.data = NULL; \
-        session->internals.handshake_recv_buffer.data = NULL; \
-        session->internals.handshake_send_buffer.size = 0; \
-        session->internals.handshake_recv_buffer.size = 0; \
+        _gnutls_buffer_clear( &session->internals.handshake_send_buffer); \
+        _gnutls_buffer_clear( &session->internals.handshake_recv_buffer); \
         session->internals.handshake_send_buffer_prev_size = 0
 
 ssize_t _gnutls_handshake_io_recv_int( gnutls_session, ContentType, HandshakeType, void *, size_t);
@@ -51,3 +47,4 @@ ssize_t _gnutls_io_write_flush( gnutls_session session);
 ssize_t _gnutls_handshake_io_write_flush( gnutls_session session);
 
 size_t gnutls_record_check_pending(gnutls_session session);
+
